@@ -2,18 +2,18 @@ from .problem import Problem
 from .backbone_autograd import backbone_autograd
 
 
-PRINT_STATUS = False
+_PRINT_STATUS = False
 
 
 try:
     from .backbone_torch import backbone_torch
 except ImportError:
-    if PRINT_STATUS:
+    if _PRINT_STATUS:
         print('Warning: cannot import backbone_torch. Possibly pytorch is not installed.')
 
 
 try:
     from .backbone_jax import backbone_jax
 except ImportError:
-    if PRINT_STATUS:
+    if _PRINT_STATUS:
         print('Warning: cannot import backbone_jax. Possibly JAX is not installed.')
\ No newline at end of file
