@@ -153,28 +153,26 @@ class symp_stiefel_jax(basic_manifold_jax):
             X = random.uniform(key, self.var_shape)
             X, R = jnp.linalg.qr(X)
 
-        if self.Feas_eval(X) > 1e-4:
-            for jl in range(10):
-                X = X - 0.5/( jnp.linalg.norm(X.T @ X, 2) )   * self.JC(X,self.C(X))
-                # X = X - 0.1  *self.JnX(X) @ self.JpM(self.C(X))
-                if self.Feas_eval(X) < 1e-3:
-                    break
-            # print(self.Feas_eval(X))
-            for jl in range(10):
-                JX = self.JnX(X)
-                XJX = X.T @ JX 
-                feas = jnp.linalg.norm( self.C(X) , 'fro')
-                
-                if feas < 1e-2:
-                    X = self.A(X)
-                else:
-                    TTT = 0.5* self.Ip - 0.5 * self.JpM( XJX) 
-                    X = jnp.linalg.solve(TTT.T, X.T ).T
-                if feas < 1e-8:
-                    break
 
+        for jl in range(10):
+            X = X - 0.5/( jnp.linalg.norm(X.T @ X, 2) )   * self.JC(X,self.C(X))
+            # X = X - 0.1  *self.JnX(X) @ self.JpM(self.C(X))
+            if self.Feas_eval(X) < 1e-3:
+                break
+        # print(self.Feas_eval(X))
+        for jl in range(10):
+            JX = self.JnX(X)
+            XJX = X.T @ JX 
+            feas = jnp.linalg.norm( self.C(X) , 'fro')
+            
+            if feas < 1e-2:
+                X = self.A(X)
+            else:
+                TTT = 0.5* self.Ip - 0.5 * self.JpM( XJX) 
+                X = jnp.linalg.solve(TTT.T, X.T ).T
+            if feas < 1e-8:
+                break
 
-        
         return X
 
     def Post_process(self,X):
