@@ -4,14 +4,16 @@ import functools
 import torch
 import numpy as np
 from collections import OrderedDict
+from torch import Tensor, DeviceObjType
+from typing import List, Tuple, Optional, Callable
 
 
-from ..manifold import basic_manifold
+from ..manifold import basic_manifold, complex_basic_manifold
 # from autograd import grad, jacobian
 # from autograd.numpy.linalg import solve, pinv
 
 class basic_manifold_torch(basic_manifold):
-    def __init__(self,name,variable_shape, constraint_shape, device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safegurad_value = 0) -> None:
+    def __init__(self,name: str,variable_shape: Tuple[int], constraint_shape: Tuple[int], device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safegurad_value = 0) -> None:
         self.name = name
         self.shape = (variable_shape,) 
         self.var_shape = variable_shape
@@ -60,23 +62,23 @@ class basic_manifold_torch(basic_manifold):
 
 
     @_raise_not_implemented_error
-    def C(self,X):
+    def C(self,X: Tensor) -> Tensor:
         """Returns the expression of the constraints
         """
 
 
 
-    def v2m(self,x):
+    def v2m(self,x: Tensor) -> Tensor:
         return torch.reshape(x, self.var_shape)
 
 
 
-    def m2v(self,X):
+    def m2v(self,X: Tensor) -> Tensor:
         return X.flatten()
 
 
 
-    def Init_point(self, Xinit = None):
+    def Init_point(self, Xinit: Tensor = None):
         Xinit = torch.randn(*self.var_shape).to(device = self.device, dtype = self.dtype)
         Xinit.requires_grad = True
         return Xinit
@@ -87,8 +89,8 @@ class basic_manifold_torch(basic_manifold):
 
     
 
-class complex_basic_manifold_torch(basic_manifold):
-    def __init__(self,name,variable_shape, constraint_shape, device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safegurad_value = 0) -> None:
+class complex_basic_manifold_torch(complex_basic_manifold):
+    def __init__(self,name:str,variable_shape: Tuple[int], constraint_shape: Tuple[int], device = torch.device('cpu'), dtype = torch.float64,  regularize_value = 0.01, safegurad_value = 0) -> None:
         self.name = name
         self.shape = (variable_shape,) 
         self.var_shape = variable_shape
@@ -141,7 +143,7 @@ class complex_basic_manifold_torch(basic_manifold):
         """Returns the expression of the constraints
         """
 
-    def array2tensor(self, X_array):
+    def array2tensor(self, X_array: np.ndarray) -> Tensor:
         dim = len(X_array)
         X_real = torch.as_tensor(X_array[:int(dim/2)])
         X_imag = torch.as_tensor(X_array[int(dim/2):])
@@ -150,7 +152,7 @@ class complex_basic_manifold_torch(basic_manifold):
         return X 
 
 
-    def tensor2array(self, X_tensor, np_dtype = np.float64):
+    def tensor2array(self, X_tensor: Tensor, np_dtype = np.float64) -> np.ndarray:
         X_real = X_tensor.real.detach().cpu().numpy()
         X_imag = X_tensor.imag.detach().cpu().numpy()
 
@@ -159,22 +161,22 @@ class complex_basic_manifold_torch(basic_manifold):
 
 
 
-    def v2m(self,x):
+    def v2m(self,x: Tensor) -> Tensor:
         return torch.reshape(x, self.var_shape)
 
 
 
-    def m2v(self,X):
+    def m2v(self,X: Tensor) -> Tensor:
         return X.flatten()
 
 
 
-    def C_quad_penalty(self, X):
+    def C_quad_penalty(self, X: Tensor):
         CX = self.C(X)
         return self.sum( CX * CX.conj())
 
 
-    def Feas_eval(self, X):
+    def Feas_eval(self, X: Tensor) -> float:
         CX = self.C(X)
         return self.sqrt(self.sum( CX * CX.conj() )).real
 
