@@ -1,6 +1,7 @@
 import numpy as np
 import torch
 from .basic_manifold_torch import basic_manifold_torch
+from torch.nn.parameter import Parameter
 
 class hyperbolic_torch(basic_manifold_torch):
     def __init__(self, var_shape, B = None, device = torch.device('cpu'), dtype = torch.float64) -> None:
@@ -44,7 +45,7 @@ class hyperbolic_torch(basic_manifold_torch):
         self.B = B 
         
         super().__init__('Hyperbolic',(n,p), (p,p),   device= self.device ,dtype= self.dtype)
-        self._parameters['In'] = torch.eye(self._p).to(device = self.device, dtype = self.dtype)
+        self._parameters['In'] = Parameter( torch.eye(self._p).to(device = self.device, dtype = self.dtype), False)
         self.Ip = self._parameters['In']
         # Here we require B be a function
         #  when one wishes to input a matrix B_mat
